@@ -39,8 +39,8 @@ class SinfoRow:
     ec2_instance_type: str
     mem: int
     cpu: int
-    vcpu: int
-    # gpu: Optional[dict]
+    vcpu: Optional[int]
+    gpu: Optional[dict]
     gpus: Optional[List]
     extra: Optional[dict]
 
